@@ -1,4 +1,4 @@
-from .adgroups import AdGroup
+from .adgroups import AdGroups
 from .bidrecommendations import BidRecommendations
 from .campaigns import Campaigns
 from .campaign_negative_keywords import CampaignNegativeKeywords
@@ -7,5 +7,6 @@ from .negative_keywords import NegativeKeywords
 from .negative_product_targeting import NegativeProductTargeting
 from .product_ads import ProductAds
 from .product_targeting import ProductTargeting
+from .reports import Reports
 from .snapshots import Snapshots
 from .suggested_keywords import SuggestedKeywords
